import { useAjax } from "@/Hook/useAjax";
import { addRoleApi, updateRoleApi } from "@/services/iaaSystem/power";
import { Form, message, Modal, Select } from "antd";
import { DefaultOptionType } from "antd/lib/select";
import React from "react"


interface Props {
    roleTypeList: DefaultOptionType[]
    userList: DefaultOptionType[]
    onChange?: () => void
    visible?: boolean
    onClose?: () => void
    initialValues?: any
}

/**
 * 新增修改用户权限
 * @returns 
 */
const ModalPower: React.FC<Props> = ({ roleTypeList, userList, onChange, visible, onClose, initialValues }) => {

    /*******************************/
    const [form] = Form.useForm();

    const addRole = useAjax((params) => addRoleApi(params))
    const updateRole = useAjax((params) => updateRoleApi(params))
    /*******************************/

    const handleOk = async () => {
        form.submit()
        let data = await form.validateFields()
        if (initialValues?.userId) {
            data.userId = initialValues?.userId
            updateRole.run(data).then(res => {
                if (res?.data) {
                    message.success('修改成功')
                    onChange && onChange()
                }
            })
        } else {
            addRole.run(data).then(res => {
                if (res?.data) {
                    message.success('新增成功')
                    onChange && onChange()
                }
            })
        }

    }

    return <Modal
        title={<strong>{initialValues?.userId ? `修改 ${initialValues?.userName} 用户权限` : '新增用户权限'}</strong>}
        open={visible}
        onCancel={onClose}
        onOk={handleOk}
        confirmLoading={addRole.loading || updateRole.loading}
    >
        <Form
            name="basicPower"
            layout="vertical"
            form={form}
            autoComplete="off"
            colon={false}
            initialValues={{ ...initialValues }}
        >
            <Form.Item label={<strong>权限类型</strong>} name="authType" rules={[{ required: true, message: '请选择权限类型!' }]}>
                <Select
                    placeholder="请选择回传策略"
                    options={roleTypeList}
                    allowClear
                />
            </Form.Item>
            {!initialValues?.userId && <Form.Item label={<strong>用户</strong>} name="userIdList" rules={[{ required: true, message: '请选择用户!' }]}>
                <Select
                    mode="multiple"
                    allowClear
                    placeholder="请选择用户"
                    options={userList}
                />
            </Form.Item>}
        </Form>
    </Modal>
}

export default React.memo(ModalPower)